# Research

Autogenerated by docs/scripts/generate-doc-index.sh

- [ARCHIVE/EXAMPLES/research/ARCHITECTURE_SUMMARY.md](../ARCHIVE/EXAMPLES/research/ARCHITECTURE_SUMMARY.md)
- [ARCHIVE/EXAMPLES/research/BACKEND_IMPLEMENTATION_PLAN.md](../ARCHIVE/EXAMPLES/research/BACKEND_IMPLEMENTATION_PLAN.md)
- [ARCHIVE/EXAMPLES/research/BACKEND_INFRASTRUCTURE_RESEARCH.md](../ARCHIVE/EXAMPLES/research/BACKEND_INFRASTRUCTURE_RESEARCH.md)
- [ARCHIVE/EXAMPLES/research/BACKEND_RECOMMENDATION.md](../ARCHIVE/EXAMPLES/research/BACKEND_RECOMMENDATION.md)
- [ARCHIVE/EXAMPLES/research/DATABASE_COMPARISON.md](../ARCHIVE/EXAMPLES/research/DATABASE_COMPARISON.md)
- [ARCHIVE/EXAMPLES/research/FRONTEND_REDESIGN.md](../ARCHIVE/EXAMPLES/research/FRONTEND_REDESIGN.md)
- [ARCHIVE/EXAMPLES/research/RESEARCH_FINDINGS.md](../ARCHIVE/EXAMPLES/research/RESEARCH_FINDINGS.md)
- [ARCHIVE/EXAMPLES/research/RESEARCH_SUMMARY.md](../ARCHIVE/EXAMPLES/research/RESEARCH_SUMMARY.md)
- [ARCHIVE/plans/005-justification-deep-analysis.md](../ARCHIVE/plans/005-justification-deep-analysis.md)
- [docs/05-research/ACADEMIC_RESEARCH_FINDINGS.md](../docs/05-research/ACADEMIC_RESEARCH_FINDINGS.md)
- [docs/05-research/ADVANCED_PYTHON_TOOLS_RESEARCH.md](../docs/05-research/ADVANCED_PYTHON_TOOLS_RESEARCH.md)
- [docs/05-research/archive/analysis-variants/COMPREHENSIVE_30_CATEGORY_ANALYSIS.md](../docs/05-research/archive/analysis-variants/COMPREHENSIVE_30_CATEGORY_ANALYSIS.md)
- [docs/05-research/archive/analysis-variants/CROSS_PROJECT_DEPENDENCY_ANALYSIS.md](../docs/05-research/archive/analysis-variants/CROSS_PROJECT_DEPENDENCY_ANALYSIS.md)
- [docs/05-research/archive/analysis-variants/MEGA_RESEARCH_FINAL_SUMMARY.md](../docs/05-research/archive/analysis-variants/MEGA_RESEARCH_FINAL_SUMMARY.md)
- [docs/05-research/archive/analysis-variants/ULTRA_COMPREHENSIVE_50_CATEGORY_ANALYSIS.md](../docs/05-research/archive/analysis-variants/ULTRA_COMPREHENSIVE_50_CATEGORY_ANALYSIS.md)
- [docs/05-research/archive/analysis-variants/ULTRA_DEEP_RESEARCH_MASTER_INDEX.md](../docs/05-research/archive/analysis-variants/ULTRA_DEEP_RESEARCH_MASTER_INDEX.md)
- [docs/05-research/archive/analysis-variants/ULTRA_RESEARCH_MASTER_INDEX.md](../docs/05-research/archive/analysis-variants/ULTRA_RESEARCH_MASTER_INDEX.md)
- [docs/05-research/archive/COMPREHENSIVE_RESEARCH_COMPLETE.md](../docs/05-research/archive/COMPREHENSIVE_RESEARCH_COMPLETE.md)
- [docs/05-research/archive/COMPREHENSIVE_RESEARCH_MASTER_INDEX.md](../docs/05-research/archive/COMPREHENSIVE_RESEARCH_MASTER_INDEX.md)
- [docs/05-research/archive/MASTER_RESEARCH_INDEX.md](../docs/05-research/archive/MASTER_RESEARCH_INDEX.md)
- [docs/05-research/archive/RESEARCH_DOCUMENTATION_INDEX.md](../docs/05-research/archive/RESEARCH_DOCUMENTATION_INDEX.md)
- [docs/05-research/archive/RESEARCH_MASTER_INDEX.md](../docs/05-research/archive/RESEARCH_MASTER_INDEX.md)
- [docs/05-research/archive/RESEARCH_STATUS_FINAL.md](../docs/05-research/archive/RESEARCH_STATUS_FINAL.md)
- [docs/05-research/archive/TRACE_RESEARCH_INDEX.md](../docs/05-research/archive/TRACE_RESEARCH_INDEX.md)
- [docs/05-research/archive/TRACE_SSOT_FEATURES_RESEARCH_INDEX.md](../docs/05-research/archive/TRACE_SSOT_FEATURES_RESEARCH_INDEX.md)
- [docs/05-research/CODE_CONSOLIDATION_ANALYSIS.md](../docs/05-research/CODE_CONSOLIDATION_ANALYSIS.md)
- [docs/05-research/CODE_REVIEW_VALIDATION.md](../docs/05-research/CODE_REVIEW_VALIDATION.md)
- [docs/05-research/COMMUNITY_STRATEGIES_GITHUB_REDDIT_ARXIV.md](../docs/05-research/COMMUNITY_STRATEGIES_GITHUB_REDDIT_ARXIV.md)
- [docs/05-research/COMPREHENSIVE_CODEBASE_ANALYSIS.md](../docs/05-research/COMPREHENSIVE_CODEBASE_ANALYSIS.md)
- [docs/05-research/COMPREHENSIVE_DEPENDENCY_ANALYSIS.md](../docs/05-research/COMPREHENSIVE_DEPENDENCY_ANALYSIS.md)
- [docs/05-research/COMPREHENSIVE_PACKAGE_MATRIX_1000_PLUS.md](../docs/05-research/COMPREHENSIVE_PACKAGE_MATRIX_1000_PLUS.md)
- [docs/05-research/COMPREHENSIVE_PYTHON_TOOLS_DEEP_RESEARCH.md](../docs/05-research/COMPREHENSIVE_PYTHON_TOOLS_DEEP_RESEARCH.md)
- [docs/05-research/DEPENDENCY_COMPARISON_MATRIX.md](../docs/05-research/DEPENDENCY_COMPARISON_MATRIX.md)
- [docs/05-research/DEPENDENCY_MIGRATION_GUIDE.md](../docs/05-research/DEPENDENCY_MIGRATION_GUIDE.md)
- [docs/05-research/DEPENDENCY_RESEARCH_INDEX.md](../docs/05-research/DEPENDENCY_RESEARCH_INDEX.md)
- [docs/05-research/ENHANCED_DEPENDENCIES_GUIDE.md](../docs/05-research/ENHANCED_DEPENDENCIES_GUIDE.md)
- [docs/05-research/GITHUB_TRENDS_ANALYSIS.md](../docs/05-research/GITHUB_TRENDS_ANALYSIS.md)
- [docs/05-research/KIMAKI_CONSOLIDATION_ANALYSIS.md](../docs/05-research/KIMAKI_CONSOLIDATION_ANALYSIS.md)
- [docs/05-research/MEGA_COMPREHENSIVE_100_CATEGORY_ANALYSIS.md](../docs/05-research/MEGA_COMPREHENSIVE_100_CATEGORY_ANALYSIS.md)
- [docs/05-research/README.md](../docs/05-research/README.md)
- [docs/05-research/rtm-deep-dives/archive/REQUIREMENTS_TRACEABILITY_BEST_PRACTICES.md](../docs/05-research/rtm-deep-dives/archive/REQUIREMENTS_TRACEABILITY_BEST_PRACTICES.md)
- [docs/05-research/rtm-deep-dives/archive/REQUIREMENTS_TRACEABILITY_COMPARISON.md](../docs/05-research/rtm-deep-dives/archive/REQUIREMENTS_TRACEABILITY_COMPARISON.md)
- [docs/05-research/rtm-deep-dives/archive/REQUIREMENTS_TRACEABILITY_GETTING_STARTED.md](../docs/05-research/rtm-deep-dives/archive/REQUIREMENTS_TRACEABILITY_GETTING_STARTED.md)
- [docs/05-research/rtm-deep-dives/archive/REQUIREMENTS_TRACEABILITY_INDEX.md](../docs/05-research/rtm-deep-dives/archive/REQUIREMENTS_TRACEABILITY_INDEX.md)
- [docs/05-research/rtm-deep-dives/archive/REQUIREMENTS_TRACEABILITY_MVP.md](../docs/05-research/rtm-deep-dives/archive/REQUIREMENTS_TRACEABILITY_MVP.md)
- [docs/05-research/rtm-deep-dives/archive/REQUIREMENTS_TRACEABILITY_RESEARCH.md](../docs/05-research/rtm-deep-dives/archive/REQUIREMENTS_TRACEABILITY_RESEARCH.md)
- [docs/05-research/rtm-deep-dives/archive/REQUIREMENTS_TRACEABILITY_ROADMAP.md](../docs/05-research/rtm-deep-dives/archive/REQUIREMENTS_TRACEABILITY_ROADMAP.md)
- [docs/05-research/rtm-deep-dives/archive/REQUIREMENTS_TRACEABILITY_SPEC.md](../docs/05-research/rtm-deep-dives/archive/REQUIREMENTS_TRACEABILITY_SPEC.md)
- [docs/05-research/rtm-deep-dives/archive/REQUIREMENTS_TRACEABILITY_SUMMARY.md](../docs/05-research/rtm-deep-dives/archive/REQUIREMENTS_TRACEABILITY_SUMMARY.md)
- [docs/05-research/rtm-deep-dives/archive/REQUIREMENTS_TRACEABILITY_USECASES.md](../docs/05-research/rtm-deep-dives/archive/REQUIREMENTS_TRACEABILITY_USECASES.md)
- [docs/05-research/rtm-deep-dives/archive/REQUIREMENTS_TRACEABILITY_VISUAL_GUIDE.md](../docs/05-research/rtm-deep-dives/archive/REQUIREMENTS_TRACEABILITY_VISUAL_GUIDE.md)
- [docs/05-research/rtm-deep-dives/README.md](../docs/05-research/rtm-deep-dives/README.md)
- [docs/05-research/rtm-deep-dives/RTM_CHAOS_ENGINEERING_SCOPE_MANAGEMENT.md](../docs/05-research/rtm-deep-dives/RTM_CHAOS_ENGINEERING_SCOPE_MANAGEMENT.md)
- [docs/05-research/rtm-deep-dives/RTM_COMPLETE_VIEW_SUMMARY.md](../docs/05-research/rtm-deep-dives/RTM_COMPLETE_VIEW_SUMMARY.md)
- [docs/05-research/rtm-deep-dives/RTM_CRUD_EXAMPLES_WALKTHROUGH.md](../docs/05-research/rtm-deep-dives/RTM_CRUD_EXAMPLES_WALKTHROUGH.md)
- [docs/05-research/rtm-deep-dives/RTM_DEEP_DIVE_ADVANCED_ARCHITECTURES.md](../docs/05-research/rtm-deep-dives/RTM_DEEP_DIVE_ADVANCED_ARCHITECTURES.md)
- [docs/05-research/rtm-deep-dives/RTM_DEEP_DIVE_AI_ML_INTEGRATION.md](../docs/05-research/rtm-deep-dives/RTM_DEEP_DIVE_AI_ML_INTEGRATION.md)
- [docs/05-research/rtm-deep-dives/RTM_DEEP_DIVE_FORMAL_METHODS.md](../docs/05-research/rtm-deep-dives/RTM_DEEP_DIVE_FORMAL_METHODS.md)
- [docs/05-research/rtm-deep-dives/RTM_DEEP_DIVE_GRAPH_DATABASES.md](../docs/05-research/rtm-deep-dives/RTM_DEEP_DIVE_GRAPH_DATABASES.md)
- [docs/05-research/rtm-deep-dives/RTM_DEEP_DIVE_MULTI_LANGUAGE_IMPLEMENTATION.md](../docs/05-research/rtm-deep-dives/RTM_DEEP_DIVE_MULTI_LANGUAGE_IMPLEMENTATION.md)
- [docs/05-research/rtm-deep-dives/RTM_DEEP_DIVE_REGULATORY_COMPLIANCE.md](../docs/05-research/rtm-deep-dives/RTM_DEEP_DIVE_REGULATORY_COMPLIANCE.md)
- [docs/05-research/rtm-deep-dives/RTM_EXPANDED_RESEARCH_SUMMARY.md](../docs/05-research/rtm-deep-dives/RTM_EXPANDED_RESEARCH_SUMMARY.md)
- [docs/05-research/rtm-deep-dives/RTM_EXTENDED_VIEWS_AND_LINKS.md](../docs/05-research/rtm-deep-dives/RTM_EXTENDED_VIEWS_AND_LINKS.md)
- [docs/05-research/rtm-deep-dives/RTM_FEATURE_GRAPH_ARCHITECTURE.md](../docs/05-research/rtm-deep-dives/RTM_FEATURE_GRAPH_ARCHITECTURE.md)
- [docs/05-research/rtm-deep-dives/RTM_FINAL_ARCHITECTURE_SUMMARY.md](../docs/05-research/rtm-deep-dives/RTM_FINAL_ARCHITECTURE_SUMMARY.md)
- [docs/05-research/rtm-deep-dives/RTM_FINAL_COMPREHENSIVE_SUMMARY.md](../docs/05-research/rtm-deep-dives/RTM_FINAL_COMPREHENSIVE_SUMMARY.md)
- [docs/05-research/rtm-deep-dives/RTM_INTELLIGENT_CRUD_SCAFFOLDING.md](../docs/05-research/rtm-deep-dives/RTM_INTELLIGENT_CRUD_SCAFFOLDING.md)
- [docs/05-research/rtm-deep-dives/RTM_INTELLIGENT_CRUD_SUMMARY.md](../docs/05-research/rtm-deep-dives/RTM_INTELLIGENT_CRUD_SUMMARY.md)
- [docs/05-research/rtm-deep-dives/RTM_MULTI_VIEW_CLI_EXAMPLES.md](../docs/05-research/rtm-deep-dives/RTM_MULTI_VIEW_CLI_EXAMPLES.md)
- [docs/05-research/rtm-deep-dives/RTM_PROJECT_STATE_VISUALIZATION.md](../docs/05-research/rtm-deep-dives/RTM_PROJECT_STATE_VISUALIZATION.md)
- [docs/05-research/rtm-deep-dives/RTM-SYSTEM-COMPREHENSIVE.md](../docs/05-research/rtm-deep-dives/RTM-SYSTEM-COMPREHENSIVE.md)
- [docs/05-research/TECH_STACK_VALIDATION.md](../docs/05-research/TECH_STACK_VALIDATION.md)
- [docs/05-research/TRACE_ADVANCED_TOOLING_INTEGRATIONS.md](../docs/05-research/TRACE_ADVANCED_TOOLING_INTEGRATIONS.md)
- [docs/05-research/TRACE_ARXIV_ACADEMIC_RESEARCH.md](../docs/05-research/TRACE_ARXIV_ACADEMIC_RESEARCH.md)
- [docs/05-research/TRACE_COMPREHENSIVE_RESEARCH_SUMMARY.md](../docs/05-research/TRACE_COMPREHENSIVE_RESEARCH_SUMMARY.md)
- [docs/05-research/TRACE_DEEP_RESEARCH_BLOGS_REDDIT_GITHUB.md](../docs/05-research/TRACE_DEEP_RESEARCH_BLOGS_REDDIT_GITHUB.md)
- [docs/05-research/TRACE_PACKAGES_TOOLS_ECOSYSTEM.md](../docs/05-research/TRACE_PACKAGES_TOOLS_ECOSYSTEM.md)
- [docs/05-research/trace-research/README.md](../docs/05-research/trace-research/README.md)
- [docs/05-research/trace-research/TRACE_ATTACHED_LAYERS_MULTIVIEW.md](../docs/05-research/trace-research/TRACE_ATTACHED_LAYERS_MULTIVIEW.md)
- [docs/05-research/trace-research/TRACE_CONSISTENCY_SYNCHRONIZATION_PATTERNS.md](../docs/05-research/trace-research/TRACE_CONSISTENCY_SYNCHRONIZATION_PATTERNS.md)
- [docs/05-research/trace-research/TRACE_FEATURES_ALGORITHMS_DEEP_DIVE.md](../docs/05-research/trace-research/TRACE_FEATURES_ALGORITHMS_DEEP_DIVE.md)
- [docs/05-research/trace-research/TRACE_PM_TOOLING_RESEARCH.md](../docs/05-research/trace-research/TRACE_PM_TOOLING_RESEARCH.md)
- [docs/05-research/trace-research/TRACE_PM_TOOLING_SUMMARY.md](../docs/05-research/trace-research/TRACE_PM_TOOLING_SUMMARY.md)
- [docs/05-research/ULTRA_DEEP_RESEARCH_ALL_PACKAGES.md](../docs/05-research/ULTRA_DEEP_RESEARCH_ALL_PACKAGES.md)
- [docs/05-research/ULTRA_STRICT_PYTHON_RESEARCH.md](../docs/05-research/ULTRA_STRICT_PYTHON_RESEARCH.md)
- [docs/05-research/USAGE_CONSOLIDATION_ANALYSIS.md](../docs/05-research/USAGE_CONSOLIDATION_ANALYSIS.md)
- [docs/reference/agent-resume/analysis/kb-013.md](../docs/reference/agent-resume/analysis/kb-013.md)
- [docs/reference/agent-resume/analysis/kb-014.md](../docs/reference/agent-resume/analysis/kb-014.md)
- [docs/reference/agent-resume/analysis/kb-015.md](../docs/reference/agent-resume/analysis/kb-015.md)
- [docs/reference/agent-resume/analysis/kb-016.md](../docs/reference/agent-resume/analysis/kb-016.md)
- [docs/reference/agent-resume/analysis/kb-017.md](../docs/reference/agent-resume/analysis/kb-017.md)
- [docs/reference/agent-resume/analysis/kb-018.md](../docs/reference/agent-resume/analysis/kb-018.md)
- [docs/reference/agent-resume/analysis/kb-019.md](../docs/reference/agent-resume/analysis/kb-019.md)
- [docs/reference/agent-resume/analysis/kb-020.md](../docs/reference/agent-resume/analysis/kb-020.md)
- [docs/reports/infrastructure-devops-analysis.md](../docs/reports/infrastructure-devops-analysis.md)
- [docs/reports/phase3-task-99-asset-optimization-analysis.md](../docs/reports/phase3-task-99-asset-optimization-analysis.md)
- [docs/reports/testing-strategy-analysis.md](../docs/reports/testing-strategy-analysis.md)
- [docs/research/00_READ_ME_FIRST_PROVENANCE_RESEARCH.md](../docs/research/00_READ_ME_FIRST_PROVENANCE_RESEARCH.md)
- [docs/research/3d-graph-libraries-evaluation.md](../docs/research/3d-graph-libraries-evaluation.md)
- [docs/research/ADDITIONAL_INTEGRATIONS_RESEARCH.md](../docs/research/ADDITIONAL_INTEGRATIONS_RESEARCH.md)
- [docs/research/ADVANCED_AI_LLM_PATTERNS_2025.md](../docs/research/ADVANCED_AI_LLM_PATTERNS_2025.md)
- [docs/research/ADVANCED_HOOK_PATTERNS_AND_MCP.md](../docs/research/ADVANCED_HOOK_PATTERNS_AND_MCP.md)
- [docs/research/ADVANCED_SPEC_OBJECTS_RESEARCH.md](../docs/research/ADVANCED_SPEC_OBJECTS_RESEARCH.md)
- [docs/research/ADVANCED_TEST_SPECIFICATIONS_RESEARCH.md](../docs/research/ADVANCED_TEST_SPECIFICATIONS_RESEARCH.md)
- [docs/research/AGENT_TIMESCALES_AND_AGENT_LED_PLANS.md](../docs/research/AGENT_TIMESCALES_AND_AGENT_LED_PLANS.md)
- [docs/research/AGGREGATION_RESEARCH_INDEX.md](../docs/research/AGGREGATION_RESEARCH_INDEX.md)
- [docs/research/AI_CODE_TESTING_2026_RESEARCH.md](../docs/research/AI_CODE_TESTING_2026_RESEARCH.md)
- [docs/research/API_GATEWAY_COMPARISON.md](../docs/research/API_GATEWAY_COMPARISON.md)
- [docs/research/API_TESTS_INDEX.md](../docs/research/API_TESTS_INDEX.md)
- [docs/research/ARCHITECTURAL_PATTERNS_DEEP_DIVE.md](../docs/research/ARCHITECTURAL_PATTERNS_DEEP_DIVE.md)
- [docs/research/BACKEND_COMMUNICATION_PROTOCOLS.md](../docs/research/BACKEND_COMMUNICATION_PROTOCOLS.md)
- [docs/research/BACKEND_INTEGRATED_SERVICES_RESEARCH.md](../docs/research/BACKEND_INTEGRATED_SERVICES_RESEARCH.md)
- [docs/research/BLEEDING_EDGE_TOOLCHAIN_UPGRADE_2025.md](../docs/research/BLEEDING_EDGE_TOOLCHAIN_UPGRADE_2025.md)
- [docs/research/BLOCKCHAIN_NFT_SPECIFICATION_PROVENANCE_RESEARCH.md](../docs/research/BLOCKCHAIN_NFT_SPECIFICATION_PROVENANCE_RESEARCH.md)
- [docs/research/BUILD_OPTIMIZATION_INDEX.md](../docs/research/BUILD_OPTIMIZATION_INDEX.md)
- [docs/research/CACHE_TEST_FILES_INDEX.md](../docs/research/CACHE_TEST_FILES_INDEX.md)
- [docs/research/CANVAS_RENDERING_INDEX.md](../docs/research/CANVAS_RENDERING_INDEX.md)
- [docs/research/canvas-libraries-evaluation.md](../docs/research/canvas-libraries-evaluation.md)
- [docs/research/CHAT_HISTORY_UI_FEATURES_INDEX.md](../docs/research/CHAT_HISTORY_UI_FEATURES_INDEX.md)
- [docs/research/CLAUDE_CODE_V4_RESEARCH_SYNTHESIS.md](../docs/research/CLAUDE_CODE_V4_RESEARCH_SYNTHESIS.md)
- [docs/research/CODEBASE_AUDIT_AND_REMAINING_WORK.md](../docs/research/CODEBASE_AUDIT_AND_REMAINING_WORK.md)
- [docs/research/CODEBASE_COMPLETION_AUDIT.md](../docs/research/CODEBASE_COMPLETION_AUDIT.md)
- [docs/research/codebase-devx-analysis.md](../docs/research/codebase-devx-analysis.md)
- [docs/research/CODEINDEX_FILES_MANIFEST.md](../docs/research/CODEINDEX_FILES_MANIFEST.md)
- [docs/research/CODEINDEX_IMPLEMENTATION.md](../docs/research/CODEINDEX_IMPLEMENTATION.md)
- [docs/research/CODEINDEX_INDEX.md](../docs/research/CODEINDEX_INDEX.md)
- [docs/research/CODEX_CLI_AGENT_INTEGRATION_RESEARCH.md](../docs/research/CODEX_CLI_AGENT_INTEGRATION_RESEARCH.md)
- [docs/research/CODEX_CLI_RESEARCH_DELIVERED.md](../docs/research/CODEX_CLI_RESEARCH_DELIVERED.md)
- [docs/research/CODEX_CLI_RESEARCH_INDEX.md](../docs/research/CODEX_CLI_RESEARCH_INDEX.md)
- [docs/research/COMPLETE_RESEARCH_STATUS.md](../docs/research/COMPLETE_RESEARCH_STATUS.md)
- [docs/research/COMPREHENSIVE_MODERN_TOOLING_PARADIGMS.md](../docs/research/COMPREHENSIVE_MODERN_TOOLING_PARADIGMS.md)
- [docs/research/COMPREHENSIVE_RESEARCH_SUMMARY.md](../docs/research/COMPREHENSIVE_RESEARCH_SUMMARY.md)
- [docs/research/CONFLICT_RESOLVER_FINAL_REPORT.md](../docs/research/CONFLICT_RESOLVER_FINAL_REPORT.md)
- [docs/research/COVERAGE_ANALYSIS_INDEX.md](../docs/research/COVERAGE_ANALYSIS_INDEX.md)
- [docs/research/COVERAGE_DAG_PLAN.md](../docs/research/COVERAGE_DAG_PLAN.md)
- [docs/research/COVERAGE_IMPROVEMENT_PLAN.md](../docs/research/COVERAGE_IMPROVEMENT_PLAN.md)
- [docs/research/CREDITPULSE_DATA_INDEX.md](../docs/research/CREDITPULSE_DATA_INDEX.md)
- [docs/research/CUSTOM_CODE_VS_OSS_AUDIT_2026-02-06.md](../docs/research/CUSTOM_CODE_VS_OSS_AUDIT_2026-02-06.md)
- [docs/research/cytoscape-js-evaluation.md](../docs/research/cytoscape-js-evaluation.md)
- [docs/research/d3-force-graph-evaluation.md](../docs/research/d3-force-graph-evaluation.md)
- [docs/research/DEFECT_SPECIFICATION_INDEX.md](../docs/research/DEFECT_SPECIFICATION_INDEX.md)
- [docs/research/DEFECT_SPECIFICATION_RESEARCH.md](../docs/research/DEFECT_SPECIFICATION_RESEARCH.md)
- [docs/research/DESKTOP_APP_RESEARCH_2025.md](../docs/research/DESKTOP_APP_RESEARCH_2025.md)
- [docs/research/devx-analysis-summary.md](../docs/research/devx-analysis-summary.md)
- [docs/research/devx-friction-matrix.md](../docs/research/devx-friction-matrix.md)
- [docs/research/DIFF_SYSTEM_INDEX.md](../docs/research/DIFF_SYSTEM_INDEX.md)
- [docs/research/DISTRIBUTED_SYSTEMS_PATTERNS_2025.md](../docs/research/DISTRIBUTED_SYSTEMS_PATTERNS_2025.md)
- [docs/research/DOCKER_SDK_RESEARCH_INDEX.md](../docs/research/DOCKER_SDK_RESEARCH_INDEX.md)
- [docs/research/DOCKER_SDK_RESEARCH.md](../docs/research/DOCKER_SDK_RESEARCH.md)
- [docs/research/E2E_ANALYSIS_INDEX.md](../docs/research/E2E_ANALYSIS_INDEX.md)
- [docs/research/E2E_IMPORT_EXPORT_INDEX.md](../docs/research/E2E_IMPORT_EXPORT_INDEX.md)
- [docs/research/EMBEDDED_CLIPROXY_AND_AGENT_SDK_RESEARCH.md](../docs/research/EMBEDDED_CLIPROXY_AND_AGENT_SDK_RESEARCH.md)
- [docs/research/EMERGING_TECHNOLOGIES_2025.md](../docs/research/EMERGING_TECHNOLOGIES_2025.md)
- [docs/research/ENHANCEMENT_RESEARCH_INDEX.md](../docs/research/ENHANCEMENT_RESEARCH_INDEX.md)
- [docs/research/ENTERPRISE_ALM_RESEARCH.md](../docs/research/ENTERPRISE_ALM_RESEARCH.md)
- [docs/research/ENV_MANAGER_COMPARISON_MATRIX.md](../docs/research/ENV_MANAGER_COMPARISON_MATRIX.md)
- [docs/research/EXECUTION_ENVIRONMENT_INDEX.md](../docs/research/EXECUTION_ENVIRONMENT_INDEX.md)
- [docs/research/EXECUTION_SERVICE_INDEX.md](../docs/research/EXECUTION_SERVICE_INDEX.md)
- [docs/research/EXTENDED_DX_COMPONENTS_RESEARCH.md](../docs/research/EXTENDED_DX_COMPONENTS_RESEARCH.md)
- [docs/research/FEATURE_GAP_ANALYSIS_COMPLETE.md](../docs/research/FEATURE_GAP_ANALYSIS_COMPLETE.md)
- [docs/research/FEATURE_GAP_ANALYSIS_SUMMARY.md](../docs/research/FEATURE_GAP_ANALYSIS_SUMMARY.md)
- [docs/research/FFMPEG_COMPREHENSIVE_RESEARCH.md](../docs/research/FFMPEG_COMPREHENSIVE_RESEARCH.md)
- [docs/research/FFMPEG_RESEARCH_INDEX.md](../docs/research/FFMPEG_RESEARCH_INDEX.md)
- [docs/research/FIGMA_AS_CODE_RESEARCH.md](../docs/research/FIGMA_AS_CODE_RESEARCH.md)
- [docs/research/FILE_STRUCTURE_LINTERS_CHECKLIST.md](../docs/research/FILE_STRUCTURE_LINTERS_CHECKLIST.md)
- [docs/research/file_structure_linters.md](../docs/research/file_structure_linters.md)
- [docs/research/FINAL_RESEARCH_INDEX.md](../docs/research/FINAL_RESEARCH_INDEX.md)
- [docs/research/FINAL_RESEARCH_SYNTHESIS.md](../docs/research/FINAL_RESEARCH_SYNTHESIS.md)
- [docs/research/FINAL_TEST_COVERAGE_REPORT_2025.md](../docs/research/FINAL_TEST_COVERAGE_REPORT_2025.md)
- [docs/research/FIX_PLAN.md](../docs/research/FIX_PLAN.md)
- [docs/research/FORMAL_METHODS_VERIFICATION_RESEARCH.md](../docs/research/FORMAL_METHODS_VERIFICATION_RESEARCH.md)
- [docs/research/FORMAL_VERIFICATION_RESEARCH_INDEX.md](../docs/research/FORMAL_VERIFICATION_RESEARCH_INDEX.md)
- [docs/research/FRONTEND_AUDIT_REPORT.md](../docs/research/FRONTEND_AUDIT_REPORT.md)
- [docs/research/FRONTEND_AUTH_ARCHITECTURE_CHANGE.md](../docs/research/FRONTEND_AUTH_ARCHITECTURE_CHANGE.md)
- [docs/research/FRONTEND_COVERAGE_INDEX.md](../docs/research/FRONTEND_COVERAGE_INDEX.md)
- [docs/research/GO_TESTING_2026_RESEARCH.md](../docs/research/GO_TESTING_2026_RESEARCH.md)
- [docs/research/GPU_FORCE_LAYOUT_RESEARCH_COMPLETE.md](../docs/research/GPU_FORCE_LAYOUT_RESEARCH_COMPLETE.md)
- [docs/research/GRAPH_DATABASE_INDEX.md](../docs/research/GRAPH_DATABASE_INDEX.md)
- [docs/research/GRAPH_DATABASE_RESEARCH.md](../docs/research/GRAPH_DATABASE_RESEARCH.md)
- [docs/research/GRAPH_LAYOUT_RESEARCH.md](../docs/research/GRAPH_LAYOUT_RESEARCH.md)
- [docs/research/GRAPH_LAYOUTS_INDEX.md](../docs/research/GRAPH_LAYOUTS_INDEX.md)
- [docs/research/GRAPH_LIBRARIES_RESEARCH_INDEX.md](../docs/research/GRAPH_LIBRARIES_RESEARCH_INDEX.md)
- [docs/research/GRAPH_NODE_EXPANSION_INDEX.md](../docs/research/GRAPH_NODE_EXPANSION_INDEX.md)
- [docs/research/GRAPH_NODE_EXPANSION_RESEARCH.md](../docs/research/GRAPH_NODE_EXPANSION_RESEARCH.md)
- [docs/research/GRAPH_RESEARCH_DELIVERY_CHECKLIST.md](../docs/research/GRAPH_RESEARCH_DELIVERY_CHECKLIST.md)
- [docs/research/graph-libraries-comprehensive-comparison.md](../docs/research/graph-libraries-comprehensive-comparison.md)
- [docs/research/graph-libraries-decision-flowchart.md](../docs/research/graph-libraries-decision-flowchart.md)
- [docs/research/HATCHET_TEMPORAL_EVALUATION.md](../docs/research/HATCHET_TEMPORAL_EVALUATION.md)
- [docs/research/HEALTH_CHECKS_INDEX.md](../docs/research/HEALTH_CHECKS_INDEX.md)
- [docs/research/INDEX__1.md](../docs/research/INDEX__1.md)
- [docs/research/INDEX_ARCHITECTURE.md](../docs/research/INDEX_ARCHITECTURE.md)
- [docs/research/INDEX_EXAMPLES.md](../docs/research/INDEX_EXAMPLES.md)
- [docs/research/INDEX_IMPLEMENTATION_STATUS.md](../docs/research/INDEX_IMPLEMENTATION_STATUS.md)
- [docs/research/INDEX_NAVIGATION.md](../docs/research/INDEX_NAVIGATION.md)
- [docs/research/INDEX.md](../docs/research/INDEX.md)
- [docs/research/INFRASTRUCTURE_TOOLING_AUDIT.md](../docs/research/INFRASTRUCTURE_TOOLING_AUDIT.md)
- [docs/research/INTEGRATION_TESTS_INDEX.md](../docs/research/INTEGRATION_TESTS_INDEX.md)
- [docs/research/INTEGRATIONS_INDEX.md](../docs/research/INTEGRATIONS_INDEX.md)
- [docs/research/ITEM_SPEC_SCHEMAS_INDEX.md](../docs/research/ITEM_SPEC_SCHEMAS_INDEX.md)
- [docs/research/JOURNEY_HANDLER_REVIEW_INDEX.md](../docs/research/JOURNEY_HANDLER_REVIEW_INDEX.md)
- [docs/research/LATEST_GREATEST_2025_TRENDS.md](../docs/research/LATEST_GREATEST_2025_TRENDS.md)
- [docs/research/LINK_CLI_TEST_COVERAGE_REPORT.md](../docs/research/LINK_CLI_TEST_COVERAGE_REPORT.md)
- [docs/research/LINTERS_RESEARCH.md](../docs/research/LINTERS_RESEARCH.md)
- [docs/research/LOAD_TESTING_INDEX.md](../docs/research/LOAD_TESTING_INDEX.md)
- [docs/research/MCP_CONSOLIDATION_INDEX.md](../docs/research/MCP_CONSOLIDATION_INDEX.md)
- [docs/research/MCP_OPTIMIZATION_INDEX.md](../docs/research/MCP_OPTIMIZATION_INDEX.md)
- [docs/research/MCP_PHASE_5_INDEX.md](../docs/research/MCP_PHASE_5_INDEX.md)
- [docs/research/MEMOIZATION_INDEX.md](../docs/research/MEMOIZATION_INDEX.md)
- [docs/research/MIGRATION_TOOLS_COMPARISON.md](../docs/research/MIGRATION_TOOLS_COMPARISON.md)
- [docs/research/MIGRATION_TOOLS_DETAILED_COMPARISON.md](../docs/research/MIGRATION_TOOLS_DETAILED_COMPARISON.md)
- [docs/research/ML_AI_RESEARCH_INDEX.md](../docs/research/ML_AI_RESEARCH_INDEX.md)
- [docs/research/ML_AI_RESEARCH_REQUIREMENTS_TESTING.md](../docs/research/ML_AI_RESEARCH_REQUIREMENTS_TESTING.md)
- [docs/research/MODERN_ENV_MANAGER_UPGRADE_ANALYSIS.md](../docs/research/MODERN_ENV_MANAGER_UPGRADE_ANALYSIS.md)
- [docs/research/MUTATION_TESTING_2026_RESEARCH.md](../docs/research/MUTATION_TESTING_2026_RESEARCH.md)
- [docs/research/NDJSON_STREAMING_INDEX.md](../docs/research/NDJSON_STREAMING_INDEX.md)
- [docs/research/NEO4J_APPROACH_COMPARISON.md](../docs/research/NEO4J_APPROACH_COMPARISON.md)
- [docs/research/ngraph-evaluation.md](../docs/research/ngraph-evaluation.md)
- [docs/research/NODE_AGGREGATION_RESEARCH.md](../docs/research/NODE_AGGREGATION_RESEARCH.md)
- [docs/research/OBSERVABILITY_OPTIONS_RESEARCH.md](../docs/research/OBSERVABILITY_OPTIONS_RESEARCH.md)
- [docs/research/OPTIMIZATION_INDEX.md](../docs/research/OPTIMIZATION_INDEX.md)
- [docs/research/OXLINT_REMEDIATION_PLAN.md](../docs/research/OXLINT_REMEDIATION_PLAN.md)
- [docs/research/OXLINT_VS_BIOME_RESEARCH.md](../docs/research/OXLINT_VS_BIOME_RESEARCH.md)
- [docs/research/PERFORMANCE_INDEXES_GUIDE.md](../docs/research/PERFORMANCE_INDEXES_GUIDE.md)
- [docs/research/PERFORMANCE_OPTIMIZATION_PLAN.md](../docs/research/PERFORMANCE_OPTIMIZATION_PLAN.md)
- [docs/research/PHASE_1_2_3_PROGRESS_REPORT.md](../docs/research/PHASE_1_2_3_PROGRESS_REPORT.md)
- [docs/research/PHASE_1_FINAL_COMPREHENSIVE_REPORT.md](../docs/research/PHASE_1_FINAL_COMPREHENSIVE_REPORT.md)
- [docs/research/PHASE_11_COMPLETION_REPORT.md](../docs/research/PHASE_11_COMPLETION_REPORT.md)
- [docs/research/PHASE_12_COMPLETION_REPORT.md](../docs/research/PHASE_12_COMPLETION_REPORT.md)
- [docs/research/PHASE_13_FINAL_COMPLETION_REPORT.md](../docs/research/PHASE_13_FINAL_COMPLETION_REPORT.md)
- [docs/research/PHASE_14C_COVERAGE_REPORT.md](../docs/research/PHASE_14C_COVERAGE_REPORT.md)
- [docs/research/PHASE_14D_COMPLETION_REPORT.md](../docs/research/PHASE_14D_COMPLETION_REPORT.md)
- [docs/research/PHASE_15A_COMPLETION_REPORT.md](../docs/research/PHASE_15A_COMPLETION_REPORT.md)
- [docs/research/PHASE_1A_COMPLETION_REPORT.md](../docs/research/PHASE_1A_COMPLETION_REPORT.md)
- [docs/research/PHASE_1A_DATABASE_FIXTURE_REPORT.md](../docs/research/PHASE_1A_DATABASE_FIXTURE_REPORT.md)
- [docs/research/PHASE_1B_CLI_COVERAGE_REPORT.md](../docs/research/PHASE_1B_CLI_COVERAGE_REPORT.md)
- [docs/research/PHASE_1B_COMPLETION_REPORT.md](../docs/research/PHASE_1B_COMPLETION_REPORT.md)
- [docs/research/PHASE_1C_TUI_COMPLETION_REPORT.md](../docs/research/PHASE_1C_TUI_COMPLETION_REPORT.md)
- [docs/research/PHASE_2_COMPLETION_REPORT.md](../docs/research/PHASE_2_COMPLETION_REPORT.md)
- [docs/research/PHASE_2_TEST_IMPLEMENTATION_REPORT.md](../docs/research/PHASE_2_TEST_IMPLEMENTATION_REPORT.md)
- [docs/research/PHASE_2C_REPOSITORIES_COMPLETION_REPORT.md](../docs/research/PHASE_2C_REPOSITORIES_COMPLETION_REPORT.md)
- [docs/research/PHASE_2D_COMPLETION_REPORT.md](../docs/research/PHASE_2D_COMPLETION_REPORT.md)
- [docs/research/PHASE_3_COVERAGE_IMPLEMENTATION_REPORT.md](../docs/research/PHASE_3_COVERAGE_IMPLEMENTATION_REPORT.md)
- [docs/research/PHASE_3C_PAGE_TESTS_REPORT.md](../docs/research/PHASE_3C_PAGE_TESTS_REPORT.md)
- [docs/research/PHASE_4_VERIFICATION_REPORT.md](../docs/research/PHASE_4_VERIFICATION_REPORT.md)
- [docs/research/PHASE_6_COMPLETION_REPORT.md](../docs/research/PHASE_6_COMPLETION_REPORT.md)
- [docs/research/PHASE_7_ASYNC_SESSION_FIX_REPORT.md](../docs/research/PHASE_7_ASYNC_SESSION_FIX_REPORT.md)
- [docs/research/PHASE_8_COMPLETION_REPORT.md](../docs/research/PHASE_8_COMPLETION_REPORT.md)
- [docs/research/PHASE_9_COMPLETION_REPORT.md](../docs/research/PHASE_9_COMPLETION_REPORT.md)
- [docs/research/PHASE_9_FINAL_STATUS_REPORT.md](../docs/research/PHASE_9_FINAL_STATUS_REPORT.md)
- [docs/research/PHASE4_TEST_INDEX.md](../docs/research/PHASE4_TEST_INDEX.md)
- [docs/research/PLAYWRIGHT_PYTHON_RESEARCH.md](../docs/research/PLAYWRIGHT_PYTHON_RESEARCH.md)
- [docs/research/PLAYWRIGHT_RESEARCH_INDEX.md](../docs/research/PLAYWRIGHT_RESEARCH_INDEX.md)
- [docs/research/PM_RESEARCH_INDEX.md](../docs/research/PM_RESEARCH_INDEX.md)
- [docs/research/PM_SPECIFICATION_PATTERNS_RESEARCH.md](../docs/research/PM_SPECIFICATION_PATTERNS_RESEARCH.md)
- [docs/research/PROBLEM_MANAGEMENT_RESEARCH.md](../docs/research/PROBLEM_MANAGEMENT_RESEARCH.md)
- [docs/research/PROCESS_MANAGERS_COMPARISON.md](../docs/research/PROCESS_MANAGERS_COMPARISON.md)
- [docs/research/PRODUCTION_RELEASE_INDEX.md](../docs/research/PRODUCTION_RELEASE_INDEX.md)
- [docs/research/PROJECT_COMPLETION_REPORT.md](../docs/research/PROJECT_COMPLETION_REPORT.md)
- [docs/research/PROVENANCE_RESEARCH_INDEX.md](../docs/research/PROVENANCE_RESEARCH_INDEX.md)
- [docs/research/PYTHON_COVERAGE_GAP_ANALYSIS.md](../docs/research/PYTHON_COVERAGE_GAP_ANALYSIS.md)
- [docs/research/PYTHON_TEST_COVERAGE_INITIATIVE_FINAL_REPORT.md](../docs/research/PYTHON_TEST_COVERAGE_INITIATIVE_FINAL_REPORT.md)
- [docs/research/PYTHON_TYPE_AND_TEST_TOOLS.md](../docs/research/PYTHON_TYPE_AND_TEST_TOOLS.md)
- [docs/research/python-and-typescript-tooling.md](../docs/research/python-and-typescript-tooling.md)
- [docs/research/QA_DOCUMENTATION_INDEX.md](../docs/research/QA_DOCUMENTATION_INDEX.md)
- [docs/research/QA_RESEARCH_INDEX.md](../docs/research/QA_RESEARCH_INDEX.md)
- [docs/research/QA_SYSTEMS_COMPREHENSIVE_RESEARCH.md](../docs/research/QA_SYSTEMS_COMPREHENSIVE_RESEARCH.md)
- [docs/research/RATE_LIMITER_INDEX.md](../docs/research/RATE_LIMITER_INDEX.md)
- [docs/research/REACT_FLOW_10K_NODES_PERFORMANCE_RESEARCH_AND_PLAN.md](../docs/research/REACT_FLOW_10K_NODES_PERFORMANCE_RESEARCH_AND_PLAN.md)
- [docs/research/reactflow-alternatives-evaluation.md](../docs/research/reactflow-alternatives-evaluation.md)
- [docs/research/README_PROBLEM_MANAGEMENT_RESEARCH.md](../docs/research/README_PROBLEM_MANAGEMENT_RESEARCH.md)
- [docs/research/README-SIGMA-RESEARCH.md](../docs/research/README-SIGMA-RESEARCH.md)
- [docs/research/REQUIREMENTS_ENHANCEMENT_LIBRARIES_RESEARCH.md](../docs/research/REQUIREMENTS_ENHANCEMENT_LIBRARIES_RESEARCH.md)
- [docs/research/RESEARCH_CANVAS_GRAPH_RENDERING.md](../docs/research/RESEARCH_CANVAS_GRAPH_RENDERING.md)
- [docs/research/RESEARCH_DELIVERY_MANIFEST.md](../docs/research/RESEARCH_DELIVERY_MANIFEST.md)
- [docs/research/RESEARCH_DELIVERY_OVERVIEW.md](../docs/research/RESEARCH_DELIVERY_OVERVIEW.md)
- [docs/research/RESEARCH_INDEX.md](../docs/research/RESEARCH_INDEX.md)
- [docs/research/RESEARCH-SUMMARY.md](../docs/research/RESEARCH-SUMMARY.md)
- [docs/research/revive-and-go-linters-comparison.md](../docs/research/revive-and-go-linters-comparison.md)
- [docs/research/ROUTES_INDEX.md](../docs/research/ROUTES_INDEX.md)
- [docs/research/SEARCH_COMPARISON_ALGOLIA_MEILISEARCH.md](../docs/research/SEARCH_COMPARISON_ALGOLIA_MEILISEARCH.md)
- [docs/research/SEARCH_TECHNICAL_REPORT.md](../docs/research/SEARCH_TECHNICAL_REPORT.md)
- [docs/research/SERVICE_HEALTH_AUTO_START.md](../docs/research/SERVICE_HEALTH_AUTO_START.md)
- [docs/research/sigma-comparison-matrix.md](../docs/research/sigma-comparison-matrix.md)
- [docs/research/sigma-js-evaluation.md](../docs/research/sigma-js-evaluation.md)
- [docs/research/sigma-js-quick-start.md](../docs/research/sigma-js-quick-start.md)
- [docs/research/sigma-js-summary.md](../docs/research/sigma-js-summary.md)
- [docs/research/SPATIAL_INDEX_IMPLEMENTATION.md](../docs/research/SPATIAL_INDEX_IMPLEMENTATION.md)
- [docs/research/SPECIFICATION_MODELS_INDEX.md](../docs/research/SPECIFICATION_MODELS_INDEX.md)
- [docs/research/SPECIFICATION_PATTERNS_INDEX.md](../docs/research/SPECIFICATION_PATTERNS_INDEX.md)
- [docs/research/SPECIFICATION_REPOSITORIES_INDEX.md](../docs/research/SPECIFICATION_REPOSITORIES_INDEX.md)
- [docs/research/SPECIFICATION_SCHEMAS_INDEX.md](../docs/research/SPECIFICATION_SCHEMAS_INDEX.md)
- [docs/research/SPECIFICATION_SERVICES_INDEX.md](../docs/research/SPECIFICATION_SERVICES_INDEX.md)
- [docs/research/SPECIFICATION_VIEWS_INDEX.md](../docs/research/SPECIFICATION_VIEWS_INDEX.md)
- [docs/research/SPECIFICATIONS_DASHBOARD_INDEX.md](../docs/research/SPECIFICATIONS_DASHBOARD_INDEX.md)
- [docs/research/SPECIFICATIONS_ROUTER_INDEX.md](../docs/research/SPECIFICATIONS_ROUTER_INDEX.md)
- [docs/research/STANDARDS_RESEARCH_COMPREHENSIVE.md](../docs/research/STANDARDS_RESEARCH_COMPREHENSIVE.md)
- [docs/research/STORYBOOK_2026_RESEARCH.md](../docs/research/STORYBOOK_2026_RESEARCH.md)
- [docs/research/STREAMING_RESEARCH_INDEX.md](../docs/research/STREAMING_RESEARCH_INDEX.md)
- [docs/research/STREAMING_RESEARCH_SUMMARY.md](../docs/research/STREAMING_RESEARCH_SUMMARY.md)
- [docs/research/streaming-technologies-comparison.md](../docs/research/streaming-technologies-comparison.md)
- [docs/research/TARGET_10_SERVICES_ANALYSIS.md](../docs/research/TARGET_10_SERVICES_ANALYSIS.md)
- [docs/research/TASK_8_INDEX.md](../docs/research/TASK_8_INDEX.md)
- [docs/research/TEST_COVERAGE_ANALYSIS_INDEX.md](../docs/research/TEST_COVERAGE_ANALYSIS_INDEX.md)
- [docs/research/TEST_COVERAGE_ANALYSIS.md](../docs/research/TEST_COVERAGE_ANALYSIS.md)
- [docs/research/TEST_COVERAGE_AUDIT_2025.md](../docs/research/TEST_COVERAGE_AUDIT_2025.md)
- [docs/research/TEST_COVERAGE_MATRIX.md](../docs/research/TEST_COVERAGE_MATRIX.md)
- [docs/research/TEST_FAILURE_ANALYSIS.md](../docs/research/TEST_FAILURE_ANALYSIS.md)
- [docs/research/TEST_ORACLE_RESEARCH_INDEX.md](../docs/research/TEST_ORACLE_RESEARCH_INDEX.md)
- [docs/research/TEST_PLAN_INDEX.md](../docs/research/TEST_PLAN_INDEX.md)
- [docs/research/TEST_SPECIFICATION_RESEARCH_INDEX.md](../docs/research/TEST_SPECIFICATION_RESEARCH_INDEX.md)
- [docs/research/TEST_SUITE_INDEX.md](../docs/research/TEST_SUITE_INDEX.md)
- [docs/research/TESTING_REPORT.md](../docs/research/TESTING_REPORT.md)
- [docs/research/THREE_TIER_ARCHITECTURE_PATTERNS.md](../docs/research/THREE_TIER_ARCHITECTURE_PATTERNS.md)
- [docs/research/TOOLING_AUDIT_INDEX.md](../docs/research/TOOLING_AUDIT_INDEX.md)
- [docs/research/TRACE_PROJECT_SPECIFIC_DX_COMPONENTS.md](../docs/research/TRACE_PROJECT_SPECIFIC_DX_COMPONENTS.md)
- [docs/research/UPSTASH_DETAILED_COMPARISON.md](../docs/research/UPSTASH_DETAILED_COMPARISON.md)
- [docs/research/UPSTASH_EVALUATION.md](../docs/research/UPSTASH_EVALUATION.md)
- [docs/research/VERCEL_AI_SDK_CLI_PROVIDERS_RESEARCH.md](../docs/research/VERCEL_AI_SDK_CLI_PROVIDERS_RESEARCH.md)
- [docs/research/VERCEL_AI_SDK_CODEX_OAUTH_RESEARCH.md](../docs/research/VERCEL_AI_SDK_CODEX_OAUTH_RESEARCH.md)
- [docs/research/VERCEL_AI_SDK_V6_INDEX.md](../docs/research/VERCEL_AI_SDK_V6_INDEX.md)
- [docs/research/VERCEL_AI_SDK_V6_RESEARCH.md](../docs/research/VERCEL_AI_SDK_V6_RESEARCH.md)
- [docs/research/VERIFICATION_INDEX.md](../docs/research/VERIFICATION_INDEX.md)
- [docs/research/VERIFICATION_REPORT.md](../docs/research/VERIFICATION_REPORT.md)
- [docs/research/VHS_COMPREHENSIVE_RESEARCH.md](../docs/research/VHS_COMPREHENSIVE_RESEARCH.md)
- [docs/research/VHS_RESEARCH_INDEX.md](../docs/research/VHS_RESEARCH_INDEX.md)
- [docs/research/VHS_RESEARCH_MANIFEST.md](../docs/research/VHS_RESEARCH_MANIFEST.md)
- [docs/research/virtual-scrolling-evaluation.md](../docs/research/virtual-scrolling-evaluation.md)
- [docs/research/VITEST_2026_RESEARCH.md](../docs/research/VITEST_2026_RESEARCH.md)
- [docs/research/VOID_ZERO_FRONTEND_PLAN.md](../docs/research/VOID_ZERO_FRONTEND_PLAN.md)
- [docs/research/VOID_ZERO_TOOLCHAIN_FRONTEND_RESEARCH.md](../docs/research/VOID_ZERO_TOOLCHAIN_FRONTEND_RESEARCH.md)
- [docs/research/WEB_E2E_BULK_OPERATIONS_INDEX.md](../docs/research/WEB_E2E_BULK_OPERATIONS_INDEX.md)
- [docs/research/WEB_E2E_INDEX.md](../docs/research/WEB_E2E_INDEX.md)
- [docs/research/web-based-devx-evaluation.md](../docs/research/web-based-devx-evaluation.md)
- [docs/research/web-devx-cost-analysis.md](../docs/research/web-devx-cost-analysis.md)
- [docs/research/webgl-graph-rendering-100k.md](../docs/research/webgl-graph-rendering-100k.md)
- [docs/site/index/research.md](../docs/site/index/research.md)
